@@ -10,7 +10,7 @@ use Carp;
 use strict;
 use warnings;
 
-our $VERSION = '0.026';
+our $VERSION = '0.22';
 
 ####
 
@@ -23,23 +23,19 @@ sub read_port {
     croak "Disconnected" unless $sock->connected;
 
     local $SIG{'ALRM'} = sub { croak "Connection timed out\n" };
-    alarm $self->{timeout};
 
-    my $msg = '';
-    do {
-        my $read;
-        my $rc = $self->socket->recv($read, $bytes - length($msg));
-        $msg .= $read;
-        if ($!{EINTR} || length($msg) == 0) {
-            # Shutdowns socket in case of timeout
-            $self->socket->shutdown(2);
+    my $msg;
+    RECEIVE : {
+        alarm $self->{timeout};
+        my $rc = $self->socket->recv($msg, $bytes);
+        alarm 0;
+        if (exists $!{EINTR} && $!{EINTR} || length($msg) == 0) {
+            redo RECEIVE;
         }
         if (!defined $rc) {
-            croak "Communication error while receiving data: $!";
+            croak "Communication error while reading request: $!";
         }
     }
-    while ($self->socket->connected && length($msg) < $bytes);        
-    alarm 0;
 
 #    say STDERR "Bytes: " . length($msg) . " MSG: " . unpack 'H*', $msg;
     $self->{buffer} = $msg;
@@ -130,30 +126,30 @@ Device::Modbus::TCP - Distribution for Modbus TCP communications
 
 =head1 SYNOPSIS
 
- #! /usr/bin/perl
- 
- use Device::Modbus::TCP::Client;
- use Data::Dumper;
- use strict;
- use warnings;
- use v5.10;
- 
- my $client = Device::Modbus::TCP::Client->new(
-     host => '192.168.1.34',
- );
- 
- my $req = $client->read_holding_registers(
-     unit     => 3,
-     address  => 2,
-     quantity => 1
- );
+#! /usr/bin/perl
 
- say Dumper $req;
- $client->send_request($req) || die "Send error: $!";
- my $response = $client->receive_response;
- say Dumper $response;
- 
- $client->disconnect;
+use Device::Modbus::TCP::Client;
+use Data::Dumper;
+use strict;
+use warnings;
+use v5.10;
+
+my $client = Device::Modbus::TCP::Client->new(
+    host => '192.168.1.34',
+);
+
+my $req = $client->read_holding_registers(
+    unit     => 3,
+    address  => 2,
+    quantity => 1
+);
+
+say Dumper $req;
+$client->send_request($req) || die "Send error: $!";
+my $response = $client->receive_response;
+say Dumper $response;
+
+$client->disconnect;
 
 =head1 DESCRIPTION
 
