@@ -59,10 +59,8 @@ sub process_request {
             $req_adu = $self->receive_request;
         }
         catch {
-            if (/Timed? out|Disconnect/i) {
-                $self->log(4, "Client timed out or disconnected: $_");
+            unless (/Time out/) {
                 $self->log(2, "Error while waiting for request: $_");
-                $self->socket->close;
             }
         };
         next unless $req_adu;
